# Deployment on Google Kubernetes Engine[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#deployment-on-google-kubernetes-engine "Permalink to this headline")

You can use the API Deployer Kubernetes integration to deploy your API Services on Google Kubernetes Engine.

## Setup[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#setup "Permalink to this headline")

### Create your GKE cluster[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#create-your-gke-cluster "Permalink to this headline")

Follow Google documentation on how to create your cluster. We recommend that you allocate at least 7 GB of memory for each cluster node.

### Prepare your local `docker` and `kubectl` commands[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#prepare-your-local-docker-and-kubectl-commands "Permalink to this headline")

Follow Google documentation to make sure that:

* Your local (on the DSS machine) `kubectl` command can interact with the cluster. As of July 2018, this implies running `gcloud container clusters get-credentials <cluster\_id>`

* Your local (on the DSS machine) `docker` command can successfully push images to the `gcr.io` repository. As of July 2018, this implies running `gcloud auth configure-docker`

### Setup the infrastructure[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#setup-the-infrastructure "Permalink to this headline")

Follow the usual setup steps as indicated in Setting up.

On GKE, there is only a single shared image repository URL, `gcr.io`. Access control is based on images names. Therefore, all images pushed by API Deployer must be prefixed by `<GCP project name>/`

For example, if your GCP project is called `my-gke-project`, all images must be prefixe by `my-gke-project/`. In addition, we recommend that you add a prefix specific to API Deployer

* Go to the infrastructure settings > Kubernetes cluster

* In the Registry host field, enter `gcr.io`

* In the images prefix field, enter `my-gke-project/dataiku-mad`

### Deploy[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#deploy "Permalink to this headline")

You’re now ready to deploy your API Services to GKE

## Using GPUs[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#using-gpus "Permalink to this headline")

Google Cloud Platform provides GPU-enabled instances with NVidia GPUs. Several steps are required in order to use them for API Deployer deployments

### Building an image with CUDA support[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#building-an-image-with-cuda-support "Permalink to this headline")

The base image that is built by default (see Setting up) does not have CUDA support and cannot use NVidia GPUs. You need to build a CUDA-enabled base image. To enable CUDA add the `--with-cuda` option to the command line:

§ ./bin/dssadmin build-base-image --type apideployer --with-cuda

We recommend that you give this image a specific tag using the `--tag` option and keep the default base image “pristine”. We also recommend that you add the DSS version number in the image tag.

§ ./bin/dssadmin build-base-image --type apideployer --with-cuda --tag dataiku-apideployer-base-cuda:X.Y.Z

where X.Y.Z is your DSS version number

Note

* This image contains CUDA 10.0 and CuDNN 7.6. You can use `--cuda-version X.Y` to specify another DSS-provided version (9.0, 10.0, 10.1, 10.2, 11.0 and 11.2 are available).

If you require other CUDA versions, you would have to create a custom image.

* Remember that depending on which CUDA version you build the base image (by default 10.0) you will need to use

the corresponding tensorflow version.

Warning

After each upgrade of DSS, you must rebuild all base images and update code envs.

If you used a specific tag, go to the infrastructure settings, and in the “Base image tag” field, enter `dataiku-apideployer-base-cuda:X.Y.Z`

### Create a cluster with GPUs[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#create-a-cluster-with-gpus "Permalink to this headline")

Follow GCP’s documentation for how to create a cluster with GPU accelerators (Note: you can also create a GPU-enabled node group in an existing cluster)

Don’t forget to run the “daemonset” installation procedure. This procedure needs several minutes to complete.

### Add a custom reservation[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#add-a-custom-reservation "Permalink to this headline")

In order for your API Deployer deployments to be located on nodes with GPU accelerators, and for GKE to configure the CUDA driver on your containers, the corresponding GKE pods must be created with a custom “limit” (in Kubernetes parlance) to indicate that you need a specific type of resource (standard resource types are CPU and memory)

You can configure this limit either at the infrastructure level (all deployments on this infrastructure will use GPUs) or at the deployment level.

#### At the infrastructure level[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#at-the-infrastructure-level "Permalink to this headline")

* Go to Infrastructure > Settings

* Go to “Sizing and Scaling”

* In the “Custom limits” section, add a new entry with key: `nvidia.com/gpu` and value: `1` (to request 1 GPU)

* Don’t forget to add the new entry, save settings

#### At the deployment level[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#at-the-deployment-level "Permalink to this headline")

* Go to Deployment > Settings

* Go to “Sizing and Scaling”

* Enable override of infrastructure settings in the “Container limits” section

* In the “Custom limits” section, add a new entry with key: `nvidia.com/gpu` and value: `1` (to request 1 GPU)

* Don’t forget to add the new entry, and save settings

### Deploy[¶](https://doc.dataiku.com/dss/latest/apinode/kubernetes/gke.html#id1 "Permalink to this headline")

You can now deploy your GPU-requiring deployments

This applies to:

* Python functions (your endpoint needs to use a code environment that includes a CUDA-using package like tensorflow-gpu)

* Python predictions (ditto)
